@@ -18,7 +18,7 @@ use Carp qw(carp croak);
 use Cwd;
 use File::Basename;
 
-our $VERSION = '0.63';
+our $VERSION = '0.65';
 
 =head1 NAME
 
@@ -85,8 +85,13 @@ The following entries will be removed from C<%ENV>:
 
     HTTP_PROXY
     http_proxy
+    HTTPS_PROXY
+    https_proxy
     CGI_HTTP_PROXY
 
+Note that L<LWP::Simple> must be loaded after this module, as it caches
+the entries in C<%ENV> otherwise.
+
 =cut
 
 sub spawn_child_win32 { my ( $self, @cmd ) = @_;
